function plotOccamIterMisfit( sFullFile );
%--------------------------------------------------------------------------    
% function plotOccamIterMisfit(sFullFile);
%
% Reads in all iteration files up to lastfile and plots up the misfit and
% roughness
%
% Kerry Key
% Scripps Institution of Oceanography
% 
% 09/01/2006 Created
% DGM Nov 2006 - updated to new iteration format & file naming convention
%--------------------------------------------------------------------------
%     ilast = str2num(sFullFile(end-1:end));
    [sPath,sName,sExt] = fileparts( sFullFile );
    ilast = str2num( sName(end-1:end) );
    
    for i = 1:ilast
%        iterfl = sprintf('ITER%02.0f',i);
%         [itrform,descr,modfile,datfile,ittime,maxitr,tolreq,iruf, ...
%          idebug,numit,pmu,rlast,tobt,ifftol,nparam,iterrho]...
%          = readITER(iterfl);
%         misfit(i) = tobt;
%         roughness(i) = rlast;
        sIterFile = sprintf( '%s%02.0f%s', sName(1:end-2), i, sExt );
        [stIter, nParamValues] = readITER( fullfile( sPath, sIterFile ) );
        misfit(i)    = stIter.nMisfit;
        roughness(i) = stIter.nRoughness;
    end
    
    % plot it:
    
    figure;
    
    % Misfit
    subplot(3,1,1)
    plot(misfit,'.-');
    xlabel('Iteration Number');
    ylabel('RMS Misfit');
    
    % Model roughness
    subplot(3,1,2); 
    plot(roughness,'.-');
    xlabel('Iteration Number');
    ylabel('Roughness');
 
    subplot(3,1,3); 
    plot(roughness,misfit,'.-');
    xlabel('Roughness');
    ylabel('Misfit');

    % New March 6, 2007: read in logfile and plot that up....
    lfile= 'LogFile.logfile';
    if ~exist(lfile,'file')
        return
    end
    fid = fopen(lfile,'r');
    if fid<0 
        return
    end
    misfit = [];
    mu = [];
    iter = 1;
    while 1
        line=fgets(fid);
        if line==-1
            break
        end
        if strfind(line,'ITERATION');
            % first save last loop
            stOCC(iter).misfit = misfit;
            stOCC(iter).mu = mu;
             
            iter = sscanf(line,' ** ITERATION      %i   **');
            misfit = []; % reset
            mu = [];
        end
        if strfind(line,'TOFMU'); 
           temp = sscanf(line,' TOFMU: MISFIT =   %g  AMU =   %g');
           misfit = [misfit, temp(1)];
           mu = [mu, temp(2)];
        end    
    end
    figure;
    for i=1:length(stOCC)
        [ y isort] = sort(stOCC(i).mu);
        plot(stOCC(i).mu(isort),stOCC(i).misfit(isort),'.-');
        hold all;
        
    end
    xlabel('Mu');ylabel('Misfit')
    legend(num2str([1:length(stOCC)]'))
    title('Misfit vs Lagrange multiplier for Occam2DMT iterations');
    
    
    
return    

%--------------------------------------------------------------------------    
function [stIter, nParams] = readITER( sFile )
%--------------------------------------------------------------------------
% readITER - read & parse an Occam2D iteration file.
%
% v1.0, July 2001 by: Kerry Key IGPP/SIO/UCSD
% v2.0, Nov 2006 by David Myer - rewritten to support new OCCAMITER_FLEX
% format files which have new entries for diagonal penalties, and roughness
% modification.  And which no longer require entries to be in a particular
% order.
%
% Parameters:
%   sFile   - path+name of iteration file to open.
% Returns:
%   stIter  - structure with members for each of the header items.  See code
%           for a list of possible members.  Structure will only have members
%           for the items that exist in the iteration file.  So not all
%           members will be present every time.
%   nParams - parameter values
%--------------------------------------------------------------------------

    % Open the iteration file
    fid = fopen( sFile, 'r' );
    
    % Default a value or two that should always exist.
    stIter.nMisfit      = 1000.0;
    stIter.nRoughness   = 0.0;
    
    % The header of the file consists of a bunch of "code: value" pairs
    % terminated by a pair that tells how many parameters there are (and is
    % immediately followed by the parameter list).
    % Read & process the pairs.
    while ~ feof(fid)
        % Get the current line & break up the code / value pair
        sLine = fgets( fid );
        [sCode, sValue] = strtok( sLine, ':' );
        sCode = lower(strtrim(sCode));
        sValue(1) = [];     % remove the leading token
        
        % If there is a user comment in the value, eliminate it.
        sValue = strtrim( strtok(sValue, '!%') );
        
        % Which code do we have?
        switch (sCode)
        case {'format'}
            stIter.sFormat = sValue;
            
        case {'description'}
            stIter.sDesc = sValue;
            
        case {'model file'}
            stIter.sModelFile = sValue;
            
        case {'data file'}
            stIter.sDataFile = sValue;
            
        case {'date/time'}
            stIter.sDateTime = sValue;
            
        case {'max iter', 'iterations to run'}
            stIter.nIterToRun = str2double( sValue );
            
        case {'req tol', 'target misfit'}
            stIter.nTargetMisfit = str2double( sValue );
            
        case {'iruf', 'roughness type'}
            stIter.nRoughnessType = str2double( sValue );
            stIter.bDiagPenalties = (stIter.nRoughnessType < 0);
            stIter.nRoughnessType = abs( stIter.nRoughnessType );
            
        case {'diagonal penalties'}
            stIter.bDiagPenalties = (str2double( sValue ) ~= 0);
            if isfield( stIter, 'nRoughnessType' )
                stIter.nRoughnessType = abs( stIter.nRoughnessType );
            end
            
        case {'debug level'}
            stIter.DebugLevel = str2double( sValue );
            
        case {'iteration'}
            stIter.nIteration = str2double( sValue );
            
        case {'pmu', 'lagrange value'}
            stIter.nLagrange = str2double( sValue );
            
        case {'rlast', 'roughness value'}
            stIter.nRoughness = str2double( sValue );
            
        case {'tlast', 'misfit value'}
            stIter.nMisfit = str2double( sValue );
            
        case {'ifftol', 'misfit reached'}
            stIter.bReachedMisfit = (str2double( sValue ) ~= 0);
            
        case {'modify roughness'}
            stIter.sModifyRoughness = sValue;
            
        case {'no. parms', 'param count'}
            stIter.nParams = str2double( sValue );
            break;	% The next thing in the file is the data param list!
            
            otherwise % do nothing
                
%         case default
%             disp( 'Error reading startup/iteration file!' );
%             error( ['Unknown or unsupported code: ' sCode] );
            
        end
        
    end
    if feof(fid) 
        error( ['Error: iteration file ' sFile ' terminated early!'] );
    end
    
    % Read the parameters
    nParams = fscanf( fid, '%f', stIter.nParams );
    
    % Close up & return
    fclose(fid);

    return
    